A validation error with path, rule, and optional message/context.
Use JSONSchex.format_error/1 to produce a human-readable string.
A validation error with path, rule, and optional message/context.
Use JSONSchex.format_error/1 to produce a human-readable string.